from setuptools import setup

setup(name='ny_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ny_probability'],
      author = 'Nagarjuna Yegavinti',
      author_email = 'yegavintin@gmail.com',
      zip_safe=False)
